==> nbdkit-1.44.1.tar.gz: nbdkit-1.44.1/tests/test-tests-set-options.sh <==
#!/usr/bin/env bash
# nbdkit
# Copyright Red Hat
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# * Neither the name of Red Hat nor the names of its contributors may be
# used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

# Check that shell script tests generally use:
#
#   source ./functions.sh
#   set -e
#   set -x
#   set -u
#
# But you're allowed to comment out the set directives if they don't
# apply to the test.

source ./functions.sh
set -e
#set -x
set -u

# Try to get a list of tests written in shell script.  An good
# approximation is to see which ones include 'functions.sh'.
tests="$( grep -l functions.sh $srcdir/test-*.sh )"

errors=0

for t in $tests; do
    echo checking $t ...
    if ! grep -Fsq -- "source ./functions.sh" $t ; then
        echo "error: $t: test does not use 'source ./functions.sh'"
        ((errors++)) ||:
    fi
    if ! grep -Fsq -- "set -e" $t ||
       ! grep -Fsq -- "set -x" $t ||
       ! grep -Fsq -- "set -u" $t ; then
        echo "error: $t: test does not contain standard options set -e, set -x and set -u"
        ((errors++)) ||:
    fi
done

if [ "$errors" -ge 1 ]; then exit 1; fi

==> nbdkit-1.44.3.tar.gz: nbdkit-1.44.3/tests/test-tests-set-options.sh <==
#!/usr/bin/env bash
# nbdkit
# Copyright Red Hat
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# * Neither the name of Red Hat nor the names of its contributors may be
# used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

# Check that shell script tests generally use:
#
#   source ./functions.sh
#   set -e
#   set -x
#   set -u
#
# But you're allowed to comment out the set directives if they don't
# apply to the test.

source ./functions.sh
set -e
#set -x
set -u

# Try to get a list of tests written in shell script.  A good
# approximation is to see which ones include 'functions.sh'.
tests="$( grep -l functions.sh $srcdir/test-*.sh )"

errors=0

for t in $tests; do
    echo checking $t ...
    if ! grep -Fsq -- "source ./functions.sh" $t ; then
        echo "error: $t: test does not use 'source ./functions.sh'"
        ((errors++)) ||:
    fi
    if ! grep -Fsq -- "set -e" $t ||
       ! grep -Fsq -- "set -x" $t ||
       ! grep -Fsq -- "set -u" $t ; then
        echo "error: $t: test does not contain standard options set -e, set -x and set -u"
        ((errors++)) ||:
    fi
done

if [ "$errors" -ge 1 ]; then exit 1; fi
